Settings — django-gwo v0.1 documentation

django-gwo v0.1 documentation

# Settings

- Table of Contents
- index
  modules
  next
  previous

- Main Page

- Installation
- Multivariate testing of dynamic pages
- Tutorial
- Getting Started
- Using the weboptimizer gdata Extension
- Management Commands
- Reference
  - Settings
  - gwo.websiteoptimizer

Enter search terms or a module, class or function name.

# Settings

© Copyright 2010, The Washington Times. Created using Sphinx 1.0.6.

Reference Settings